@@ -4,7 +4,8 @@ This module contains the ``analysis`` class.
 It includes common classes for file management and messaging and all
 calls to AEDT modules like the modeler, mesh, postprocessing, and setup.
 """
-from __future__ import absolute_import
+
+from __future__ import absolute_import  # noreorder
 
 import os
 import shutil
@@ -12,32 +13,30 @@ import threading
 import warnings
 from collections import OrderedDict
 
-from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, filter_tuple
-from pyaedt.generic.constants import (
-    AXIS,
-    PLANE,
-    GRAVITY,
-    VIEW,
-    SOLUTIONS,
-    SETUPS,
-    CoordinateSystemPlane,
-    CoordinateSystemAxis,
-    Plane,
-    GravityDirection,
-)
-from pyaedt.modules.Boundary import NativeComponentObject
-from pyaedt.modules.DesignXPloration import (
-    DOESetups,
-    DXSetups,
-    OptimizationSetups,
-    ParametericsSetups,
-    SensitivitySetups,
-    StatisticalSetups,
-)
-from pyaedt.modules.MaterialLib import Materials
-from pyaedt.modules.SolveSetup import Setup
 from pyaedt.application.Design import Design
 from pyaedt.application.JobManager import update_hpc_option
+from pyaedt.generic.constants import AXIS
+from pyaedt.generic.constants import CoordinateSystemAxis
+from pyaedt.generic.constants import CoordinateSystemPlane
+from pyaedt.generic.constants import GRAVITY
+from pyaedt.generic.constants import GravityDirection
+from pyaedt.generic.constants import PLANE
+from pyaedt.generic.constants import Plane
+from pyaedt.generic.constants import SETUPS
+from pyaedt.generic.constants import SOLUTIONS
+from pyaedt.generic.constants import VIEW
+from pyaedt.generic.general_methods import filter_tuple
+from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import pyaedt_function_handler
+from pyaedt.modules.Boundary import NativeComponentObject
+from pyaedt.modules.DesignXPloration import DOESetups
+from pyaedt.modules.DesignXPloration import DXSetups
+from pyaedt.modules.DesignXPloration import OptimizationSetups
+from pyaedt.modules.DesignXPloration import ParametericsSetups
+from pyaedt.modules.DesignXPloration import SensitivitySetups
+from pyaedt.modules.DesignXPloration import StatisticalSetups
+from pyaedt.modules.MaterialLib import Materials
+from pyaedt.modules.SolveSetup import Setup
 
 
 class Analysis(Design, object):
@@ -505,7 +504,7 @@ class Analysis(Design, object):
         except:
             return []
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_excitations_name(self):
         """Get all excitation names.
 
@@ -526,7 +525,7 @@ class Analysis(Design, object):
         warnings.warn("`get_excitations_name` is deprecated. Use `excitations` property instead.", DeprecationWarning)
         return self.excitations
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_traces_for_plot(
         self,
         get_self_terms=True,
@@ -585,9 +584,9 @@ class Analysis(Design, object):
                             list_output.append(value)
         return list_output
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def analyze_all(self):
-        """Analyze all setup in an actual design.
+        """Analyze all setups in a design.
 
         Returns
         -------
@@ -597,7 +596,7 @@ class Analysis(Design, object):
         self.odesign.AnalyzeAll()
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def list_of_variations(self, setup_name=None, sweep_name=None):
         """Retrieve a list of active variations for input setup.
 
@@ -642,7 +641,7 @@ class Analysis(Design, object):
             except:
                 return [""]
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def export_results(self, analyze=False, export_folder=None):
         """Export all available reports to a file, including sNp, profile, and convergence.
 
@@ -775,7 +774,7 @@ class Analysis(Design, object):
                                 self.logger.warning("Export SnP failed: no solutions found")
         return exported_files
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def export_convergence(self, setup_name, variation_string="", file_path=None):
         """Export a solution convergence to a file.
 
@@ -806,7 +805,7 @@ class Analysis(Design, object):
         self.logger.info("Export Convergence to  %s", file_path)
         return file_path
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _get_native_data(self):
         """Retrieve Native Components data."""
         boundaries = []
@@ -868,7 +867,7 @@ class Analysis(Design, object):
             """
             return [i for i in self._app.variable_manager.independent_variables]
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def variations(self, setup_sweep=None):
             """Variations.
 
@@ -904,7 +903,7 @@ class Analysis(Design, object):
                 families.append(family)
             return families
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def get_variation_strings(self, setup_sweep=None):
             """Return variation strings.
 
@@ -975,7 +974,7 @@ class Analysis(Design, object):
             >>> oDesign.GetVariableValue
             >>> oDesign.GetNominalVariation"""
             families = {}
-            if self._app.design_type == "HFSS 3D Layout Design":
+            if self._app.design_type in ["HFSS 3D Layout Design", "Circuit Design", "Twin Builder"]:
                 if self._app._is_object_oriented_enabled():
                     listvar = list(self._app._odesign.GetChildObject("Variables").GetChildNames())
                 else:
@@ -1002,7 +1001,7 @@ class Analysis(Design, object):
 
         (XNeg, YNeg, ZNeg, XPos, YPos, ZPos) = range(0, 6)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_setups(self):
         """Retrieve setups.
 
@@ -1019,7 +1018,7 @@ class Analysis(Design, object):
         setups = self.oanalysis.GetSetups()
         return list(setups)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_nominal_variation(self):
         """Retrieve the nominal variation.
 
@@ -1030,7 +1029,7 @@ class Analysis(Design, object):
         """
         return self.available_variations.nominal
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_sweeps(self, name):
         """Retrieve all sweeps for a setup.
 
@@ -1052,7 +1051,7 @@ class Analysis(Design, object):
         sweeps = self.oanalysis.GetSweeps(name)
         return list(sweeps)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def export_parametric_results(self, sweepname, filename, exportunits=True):
         """Export a list of all parametric variations solved for a sweep to a CSV file.
 
@@ -1080,7 +1079,7 @@ class Analysis(Design, object):
         self.ooptimetrics.ExportParametricResults(sweepname, filename, exportunits)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def analyze_from_initial_mesh(self):
         """Revert the solution to the initial mesh and re-run the solve.
 
@@ -1099,7 +1098,7 @@ class Analysis(Design, object):
         self.analyze_nominal()
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def analyse_nominal(self):
         """Solve the nominal design.
 
@@ -1109,7 +1108,7 @@ class Analysis(Design, object):
         warnings.warn("`analyse_nominal` is deprecated. Use `analyze_nominal` instead.", DeprecationWarning)
         self.analyze_nominal()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def analyze_nominal(self, num_cores=None, num_tasks=None, num_gpu=None, acf_file=None):
         """Solve the nominal design.
 
@@ -1137,7 +1136,7 @@ class Analysis(Design, object):
 
         return self.analyze_setup(self.analysis_setup, num_cores, num_tasks, num_gpu, acf_file)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def generate_unique_setup_name(self, setup_name=None):
         """Generate a new setup with an unique name.
 
@@ -1160,7 +1159,7 @@ class Analysis(Design, object):
             index += 1
         return setup_name
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_setup(self, setupname="MySetupAuto", setuptype=None, props={}):
         """Create a setup.
 
@@ -1229,7 +1228,7 @@ class Analysis(Design, object):
         self.setups.append(setup)
         return setup
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete_setup(self, setupname):
         """Delete a setup.
 
@@ -1267,7 +1266,7 @@ class Analysis(Design, object):
             return True
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def edit_setup(self, setupname, properties_dict):
         """Modify a setup.
 
@@ -1294,7 +1293,7 @@ class Analysis(Design, object):
         self.analysis_setup = setupname
         return setup
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_setup(self, setupname):
         """Get the setup from the current design.
 
@@ -1315,7 +1314,7 @@ class Analysis(Design, object):
             self.analysis_setup = setupname
         return setup
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_output_variable(self, variable, expression):
         """Create or modify an output variable.
 
@@ -1346,7 +1345,7 @@ class Analysis(Design, object):
             oModule.CreateOutputVariable(variable, expression, self.existing_analysis_sweeps[0], self.solution_type, [])
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_output_variable(self, variable):
         """Retrieve the value of the output variable.
 
@@ -1368,14 +1367,13 @@ class Analysis(Design, object):
         """
         assert variable in self.output_variables, "Output variable {} does not exist.".format(variable)
         nominal_variation = self.odesign.GetNominalVariation()
-        sol_type = self.solution_type
         value = self.ooutput_variable.GetOutputVariableValue(
             variable, nominal_variation, self.existing_analysis_sweeps[0], self.solution_type, []
         )
 
         return value
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_object_material_properties(self, object_list=None, prop_names=None):
         """Retrieve the material properties for a list of objects and return them in a dictionary.
 
@@ -1417,22 +1415,22 @@ class Analysis(Design, object):
                     dict[entry][prop_name] = mat_props._props[prop_name]
         return dict
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def analyze_setup(self, name, num_cores=None, num_tasks=None, num_gpu=None, acf_file=None):
-        """Analyze a specific design setup.
+        """Analyze a design setup.
 
         Parameters
         ----------
         name : str
             Name of the setup, which can be an optimetric setup or a simple setup.
         num_cores : int, optional
-            Number of Simulation cores.
+            Number of simulation cores. The default is ``None.``
         num_tasks : int, optional
-            Number of Simulation tasks.
+            Number of simulation tasks. The default is ``None.``
         num_gpu : int, optional
-            Number of Simulation Gpu to use.
+            Number of simulation graphics processing units. The default is ``None.``
         acf_file : str, optional
-            Full path to custom acf_file.
+            Full path to custom ACF file. The default is ``None.``
 
         Returns
         -------
@@ -1506,7 +1504,7 @@ class Analysis(Design, object):
         self.logger.info("Design setup %s solved correctly", name)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def solve_in_batch(self, filename=None, machine="local", run_in_thread=False):
         """Analyze a design setup in batch mode.
 
@@ -1568,7 +1566,7 @@ class Analysis(Design, object):
         self.logger.info("Batch job finished.")
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def submit_job(
         self, clustername, aedt_full_exe_path=None, numnodes=1, numcores=32, wait_for_license=True, setting_file=None
     ):
