@@ -2,10 +2,12 @@ import ntpath
 import os
 import warnings
 
-from pyaedt.generic.general_methods import aedt_exception_handler, _retry_ntimes, is_ironpython
+from pyaedt.application.Analysis import Analysis
+from pyaedt.generic.general_methods import _retry_ntimes
+from pyaedt.generic.general_methods import is_ironpython
+from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.Model3D import Modeler3D
 from pyaedt.modules.Mesh import Mesh
-from pyaedt.application.Analysis import Analysis
 
 if is_ironpython:
     from pyaedt.modules.PostProcessor import PostProcessor
@@ -165,7 +167,7 @@ class FieldAnalysis3D(Analysis, object):
                 components_dict[tail[:-8]] = el
         return components_dict
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def plot(
         self,
         objects=None,
@@ -221,7 +223,7 @@ class FieldAnalysis3D(Analysis, object):
                 clean_files=clean_files,
             )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def export_mesh_stats(self, setup_name, variation_string="", mesh_path=None):
         """Export mesh statistics to a file.
 
@@ -249,7 +251,7 @@ class FieldAnalysis3D(Analysis, object):
         self.odesign.ExportMeshStats(setup_name, variation_string, mesh_path)
         return mesh_path
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_components3d_vars(self, component3dname):
         """Read the A3DCOMP file and check for variables.
 
@@ -296,7 +298,7 @@ class FieldAnalysis3D(Analysis, object):
                 vars[line_list[1]] = line_list[len(line_list) - 2]
         return vars
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_property_value(self, objectname, property, type=None):
         """Retrieve a property value.
 
@@ -359,7 +361,7 @@ class FieldAnalysis3D(Analysis, object):
         return None
 
     # TODO Refactor this
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def copy_solid_bodies_from(self, design, object_list=None, no_vacuum=True, no_pec=True, include_sheets=False):
         """Copy a list of objects from one design to the active design.
 
@@ -412,7 +414,7 @@ class FieldAnalysis3D(Analysis, object):
         self.modeler.refresh_all_ids()
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def export3DModel(self, fileName, filePath, fileFormat=".step", object_list=[], removed_objects=[]):
         """Export the 3D model.
 
@@ -423,7 +425,7 @@ class FieldAnalysis3D(Analysis, object):
         warnings.warn("`export3DModel` is deprecated. Use `export_3d_model` instead.", DeprecationWarning)
         return self.export_3d_model(fileName, filePath, fileFormat, object_list, removed_objects)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def export_3d_model(self, fileName, filePath, fileFormat=".step", object_list=[], removed_objects=[]):
         """Export the 3D model.
 
@@ -465,7 +467,7 @@ class FieldAnalysis3D(Analysis, object):
         major = -1
         minor = -1
         # actual version supported by AEDT is 29.0
-        if fileFormat in [".step", ".stp", ".sm3", ".sat", ".sab"]:
+        if fileFormat in [".sm3", ".sat", ".sab"]:
             major = 29
             minor = 0
         stringa = ",".join(allObjects)
@@ -478,7 +480,7 @@ class FieldAnalysis3D(Analysis, object):
             "Selections:=",
             stringa,
             "File Name:=",
-            os.path.join(filePath, fileName + fileFormat),
+            os.path.join(filePath, fileName + fileFormat).replace("\\", "/"),
             "Major Version:=",
             major,
             "Minor Version:=",
@@ -488,7 +490,7 @@ class FieldAnalysis3D(Analysis, object):
         self.modeler.oeditor.Export(arg)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_all_sources(self):
         """Retrieve all setup sources.
 
@@ -504,7 +506,7 @@ class FieldAnalysis3D(Analysis, object):
         """
         return list(self.osolution.GetAllSources())
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def set_source_context(self, sources, number_of_modes=1):
         """Set the source context.
 
@@ -532,7 +534,7 @@ class FieldAnalysis3D(Analysis, object):
         self.osolution.SetSourceContexts(contexts)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_material(self, obj, mat):
         """Assign a material to one or more objects.
 
@@ -600,7 +602,7 @@ class FieldAnalysis3D(Analysis, object):
             self.logger.error("Material does not exist.")
             return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_all_conductors_names(self):
         """Retrieve all conductors in the active design.
 
@@ -621,7 +623,7 @@ class FieldAnalysis3D(Analysis, object):
             obj_names += list(self._modeler.oeditor.GetObjectsByMaterial(el))
         return obj_names
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_all_dielectrics_names(self):
         """Retrieve all dielectrics in the active design.
 
