@@ -1,10 +1,12 @@
-import time
-import warnings
 import math
 import os
+import time
+import warnings
+from collections import OrderedDict
 
-from pyaedt.generic.general_methods import aedt_exception_handler, is_ironpython
 from pyaedt.edb_core.general import convert_py_list_to_net_list
+from pyaedt.generic.general_methods import is_ironpython
+from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.GeometryOperators import GeometryOperators
 
 try:
@@ -31,16 +33,12 @@ class EDBNetsData(object):
     """
 
     def __getattr__(self, key):
-        if key in dir(self):
-            try:
-                return getattr(self, key)
-            except:
-                raise AttributeError("Attribute not present")
-
-        if key in dir(self.net_object):
+        try:
+            return self[key]
+        except:
             try:
                 return getattr(self.net_object, key)
-            except:
+            except AttributeError:
                 raise AttributeError("Attribute not present")
 
     def __init__(self, raw_net, core_app):
@@ -108,7 +106,7 @@ class EDBNetsData(object):
                 comps[el] = val
         return comps
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def plot(self, layers=None, show_legend=True, save_plot=None, outline=None, size=(2000, 1000)):
         """Plot a Net to Matplotlib 2D Chart.
 
@@ -147,16 +145,12 @@ class EDBPrimitives(object):
     """
 
     def __getattr__(self, key):
-        if key in dir(self):
-            try:
-                return getattr(self, key)
-            except:
-                raise AttributeError("Attribute not present")
-
-        if key in dir(self.primitive_object):
+        try:
+            return self[key]
+        except:
             try:
                 return getattr(self.primitive_object, key)
-            except:
+            except AttributeError:
                 raise AttributeError("Attribute not present")
 
     def __init__(self, raw_primitive, core_app):
@@ -165,7 +159,7 @@ class EDBPrimitives(object):
         self._core_net = core_app.core_nets
         self.primitive_object = raw_primitive
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def area(self, include_voids=True):
         """Return the total area.
 
@@ -191,6 +185,8 @@ class EDBPrimitives(object):
         -------
         bool
         """
+        if not hasattr(self.primitive_object, "IsVoid"):
+            return False
         return self.primitive_object.IsVoid()
 
     @staticmethod
@@ -293,7 +289,7 @@ class EDBPrimitives(object):
         # fmt: on
         return x, y
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def points(self, arc_segments=6):
         """Return the list of points with arcs converted to segments.
 
@@ -332,7 +328,7 @@ class EDBPrimitives(object):
             voids.append(EDBPrimitives(void, self._app))
         return voids
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def points_raw(self):
         """Return a list of Edb points.
 
@@ -350,7 +346,7 @@ class EDBPrimitives(object):
         except:
             return points
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def is_arc(self, point):
         """Either if a point is an arc or not.
 
@@ -431,7 +427,7 @@ class EDBPrimitives(object):
         else:
             raise AttributeError("Value inserted not found. Input has to be layer name or layer object.")
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete(self):
         """Delete this primtive."""
         self.primitive_object.Delete()
@@ -477,10 +473,9 @@ class EDBLayer(object):
         """Logger."""
         return self._pedblayers.logger
 
-    @property
-    def _edb_value(self):
-        """Edb Value."""
-        return self._pedblayers._edb_value
+    def _get_edb_value(self, value):
+        """Get Edb Value."""
+        return self._pedblayers._get_edb_value(value)
 
     @property
     def name(self):
@@ -554,11 +549,11 @@ class EDBLayer(object):
 
         Returns
         -------
-        str
+        float
             Thickness value.
         """
         try:
-            self._thickness = self._layer.GetThicknessValue().ToString()
+            self._thickness = self._layer.GetThicknessValue().ToDouble()
         except:
             pass
         return self._thickness
@@ -673,7 +668,7 @@ class EDBLayer(object):
             self._etch_factor = value
             self.update_layers()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def plot(self, nets=None, show_legend=True, save_plot=None, outline=None, size=(2000, 1000)):
         """Plot a Layer to Matplotlib 2D Chart.
 
@@ -703,7 +698,7 @@ class EDBLayer(object):
             size=size,
         )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def init_vals(self):
         """Initialize values."""
         try:
@@ -720,7 +715,7 @@ class EDBLayer(object):
         except:
             pass
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def update_layer_vals(self, layerName, newLayer, etchMap, materialMap, fillMaterialMap, thicknessMap, layerTypeMap):
         """Update layer properties.
 
@@ -752,7 +747,7 @@ class EDBLayer(object):
             self._logger.error("Layer %s has unknown type %s.", layerName, layerTypeMap)
             return False
         if thicknessMap:
-            newLayer.SetThickness(self._edb_value(thicknessMap))
+            newLayer.SetThickness(self._get_edb_value(thicknessMap))
         if materialMap:
             newLayer.SetMaterial(materialMap)
         if fillMaterialMap:
@@ -763,10 +758,10 @@ class EDBLayer(object):
             etchVal = 0.0
         if etchVal != 0.0:
             newLayer.SetEtchFactorEnabled(True)
-            newLayer.SetEtchFactor(self._edb_value(etchVal))
+            newLayer.SetEtchFactor(self._get_edb_value(etchVal))
         return newLayer
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def set_elevation(self, layer, elev):
         """Update the layer elevation.
 
@@ -783,10 +778,11 @@ class EDBLayer(object):
             Layer
 
         """
-        layer.SetLowerElevation(self._edb_value(elev))
+
+        layer.SetLowerElevation(self._get_edb_value(elev))
         return layer
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def update_layers(self):
         """Update all layers.
 
@@ -885,9 +881,8 @@ class EDBLayers(object):
     def _edb(self):
         return self._pedbstackup._edb
 
-    @property
-    def _edb_value(self):
-        return self._pedbstackup._edb_value
+    def _get_edb_value(self, value):
+        return self._pedbstackup._get_edb_value(value)
 
     @property
     def _builder(self):
@@ -939,7 +934,7 @@ class EDBLayers(object):
         dict[str, :class:`pyaedt.edb_core.EDB_Data.EDBLayer`]
             Dictionary of signal layers.
         """
-        self._signal_layers = {}
+        self._signal_layers = OrderedDict({})
         for layer, edblayer in self.layers.items():
             if (
                 edblayer._layer_type == self._edb.Cell.LayerType.SignalLayer
@@ -996,7 +991,7 @@ class EDBLayers(object):
         """Logger."""
         return self._pedbstackup.logger
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _int_to_layer_types(self, val):
         if int(val) == 0:
             return self.layer_types.SignalLayer
@@ -1041,15 +1036,15 @@ class EDBLayers(object):
         elif value == 2 or value == self.layer_collection_mode.MultiZone:
             self.layer_collection.SetMode(self.layer_collection_mode.MultiZone)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _update_edb_objects(self):
-        self._edb_object = {}
+        self._edb_object = OrderedDict({})
         layers = self.edb_layers
         for i in range(len(layers)):
             self._edb_object[layers[i].GetName()] = EDBLayer(layers[i], self)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_layer(
         self,
         layerName,
@@ -1088,50 +1083,61 @@ class EDBLayers(object):
         thisLC = self._pedbstackup._active_layout.GetLayerCollection()
         layers = list(list(thisLC.Layers(self._edb.Cell.LayerTypeSet.AllLayerSet)))
         layers.reverse()
-        newLayers = List[self._edb.Cell.Layer]()
+        # newLayers = List[self._edb.Cell.Layer]()
         el = 0.0
+        lcNew = self._edb.Cell.LayerCollection()
+
         if not layers or not start_layer:
             if int(layerType) > 2:
                 newLayer = self._edb.Cell.Layer(layerName, self._int_to_layer_types(layerType))
-                newLayers.Add(newLayer)
+                # newLayers.Add(newLayer)
+                lcNew.AddLayerTop(newLayer)
             else:
+                for lyr in layers:
+                    if not lyr.IsStackupLayer():
+                        # newLayers.Add(lyr.Clone())
+                        lcNew.AddLayerTop(lyr.Clone())
+                        continue
                 newLayer = self._edb.Cell.StackupLayer(
                     layerName,
                     self._int_to_layer_types(layerType),
-                    self._edb_value(0),
-                    self._edb_value(0),
+                    self._get_edb_value(0),
+                    self._get_edb_value(0),
                     "",
                 )
-                newLayers.Add(newLayer)
                 self._edb_object[layerName] = EDBLayer(newLayer, self._pedbstackup)
                 newLayer = self._edb_object[layerName].update_layer_vals(
                     layerName, newLayer, etchMap, material, fillMaterial, thickness, self._int_to_layer_types(layerType)
                 )
-                newLayer = self._edb_object[layerName].set_elevation(newLayer, el)
+                newLayer.SetLowerElevation(self._get_edb_value(el))
+
+                # newLayers.Add(newLayer)
+                lcNew.AddLayerTop(newLayer)
                 el += newLayer.GetThickness()
             for lyr in layers:
                 if not lyr.IsStackupLayer():
-                    newLayers.Add(lyr.Clone())
                     continue
                 newLayer = lyr.Clone()
-                newLayer = self._edb_object[lyr.GetName()].set_elevation(newLayer, el)
+                newLayer.SetLowerElevation(self._get_edb_value(el))
                 el += newLayer.GetThickness()
-                newLayers.Add(newLayer)
+                # newLayers.Add(newLayer)
+                lcNew.AddLayerTop(newLayer)
         else:
             for lyr in layers:
                 if not lyr.IsStackupLayer():
-                    newLayers.Add(lyr.Clone())
+                    # newLayers.Add(lyr.Clone())
+                    lcNew.AddLayerTop(lyr.Clone())
                     continue
                 if lyr.GetName() == start_layer:
-                    newLayer = lyr.Clone()
-                    el += newLayer.GetThickness()
-                    newLayers.Add(newLayer)
-
+                    original_layer = lyr.Clone()
+                    original_layer.SetLowerElevation(self._get_edb_value(el))
+                    lcNew.AddLayerTop(original_layer)
+                    el += original_layer.GetThickness()
                     newLayer = self._edb.Cell.StackupLayer(
                         layerName,
                         self._int_to_layer_types(layerType),
-                        self._edb_value(0),
-                        self._edb_value(0),
+                        self._get_edb_value(0),
+                        self._get_edb_value(0),
                         "",
                     )
                     self._edb_object[layerName] = EDBLayer(newLayer, self._pedbstackup)
@@ -1144,16 +1150,19 @@ class EDBLayers(object):
                         thickness,
                         self._int_to_layer_types(layerType),
                     )
-                    newLayer = self._edb_object[layerName].set_elevation(newLayer, el)
+                    newLayer.SetLowerElevation(self._get_edb_value(el))
+                    lcNew.AddLayerTop(newLayer)
                     el += newLayer.GetThickness()
+                    # newLayers.Add(original_layer)
+
                 else:
                     newLayer = lyr.Clone()
-                    newLayer = self._edb_object[lyr.GetName()].set_elevation(newLayer, el)
+                    newLayer.SetLowerElevation(self._get_edb_value(el))
                     el += newLayer.GetThickness()
-                newLayers.Add(newLayer)
-        lcNew = self._edb.Cell.LayerCollection()
-        newLayers.Reverse()
-        if not lcNew.AddLayers(newLayers) or not self._active_layout.SetLayerCollection(lcNew):
+                    lcNew.AddLayerTop(newLayer)
+        # lcNew = self._edb.Cell.LayerCollection()
+        # newLayers.Reverse()
+        if not self._active_layout.SetLayerCollection(lcNew):
             self._logger.error("Failed to set new layers when updating the stackup information.")
             return False
         self._update_edb_objects()
@@ -1179,7 +1188,7 @@ class EDBLayers(object):
         else:
             return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def remove_layer(self, layername):
         """Remove a layer.
 
@@ -1260,9 +1269,8 @@ class EDBPadProperties(object):
     def _edb(self):
         return self._pedbpadstack._edb
 
-    @property
-    def _edb_value(self):
-        return self._pedbpadstack._edb_value
+    def _get_edb_value(self, value):
+        return self._pedbpadstack._get_edb_value(value)
 
     @property
     def geometry_type(self):
@@ -1282,7 +1290,7 @@ class EDBPadProperties(object):
         shape.8, Round gap with 45 degree thermal ties. 9, Round gap with 90 degree thermal ties.10, Square gap
         with 45 degree thermal ties. 11, Square gap with 90 degree thermal ties.
         """
-        val = self._edb_value(0)
+        val = self._get_edb_value(0)
         params = []
         if geom_type == 0:
             pass
@@ -1343,9 +1351,9 @@ class EDBPadProperties(object):
     def parameters(self, propertylist):
 
         if not isinstance(propertylist, list):
-            propertylist = [self._edb_value(propertylist)]
+            propertylist = [self._get_edb_value(propertylist)]
         else:
-            propertylist = [self._edb_value(i) for i in propertylist]
+            propertylist = [self._get_edb_value(i) for i in propertylist]
         self._update_pad_parameters_parameters(params=propertylist)
 
     @property
@@ -1399,7 +1407,7 @@ class EDBPadProperties(object):
 
         self._update_pad_parameters_parameters(rotation=rotation_value)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def int_to_geometry_type(self, val=0):
         """Convert an integer to an EDB.PadGeometryType.
 
@@ -1439,7 +1447,7 @@ class EDBPadProperties(object):
         elif val == 12:
             return self._edb.Definition.PadGeometryType.InvalidGeometry
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _update_pad_parameters_parameters(
         self, layer_name=None, pad_type=None, geom_type=None, params=None, offsetx=None, offsety=None, rotation=None
     ):
@@ -1474,7 +1482,7 @@ class EDBPadProperties(object):
         if not geom_type:
             geom_type = self.geometry_type
         if not params:
-            params = [self._edb_value(i) for i in self.parameters]
+            params = [self._get_edb_value(i) for i in self.parameters]
         if not offsetx:
             offsetx = self.offset_x
         if not offsety:
@@ -1491,9 +1499,9 @@ class EDBPadProperties(object):
             pad_type,
             geom_type,
             convert_py_list_to_net_list(params),
-            self._edb_value(offsetx),
-            self._edb_value(offsety),
-            self._edb_value(rotation),
+            self._get_edb_value(offsetx),
+            self._get_edb_value(offsety),
+            self._get_edb_value(rotation),
         )
         self._edb_padstack.SetData(newPadstackDefinitionData)
 
@@ -1543,9 +1551,8 @@ class EDBPadstack(object):
     def _edb(self):
         return self._ppadstack._edb
 
-    @property
-    def _edb_value(self):
-        return self._ppadstack._edb_value
+    def _get_edb_value(self, value):
+        return self._ppadstack._get_edb_value(value)
 
     @property
     def via_layers(self):
@@ -1586,7 +1593,7 @@ class EDBPadstack(object):
         if is_ironpython:
             out = viaData.GetHoleParametersValue()
         else:
-            value0 = self._edb_value("0.0")
+            value0 = self._get_edb_value("0.0")
             ptype = self._edb.Definition.PadGeometryType.Circle
             HoleParam = Array[type(value0)]([])
             out = viaData.GetHoleParametersValue(ptype, HoleParam, value0, value0, value0)
@@ -1604,7 +1611,7 @@ class EDBPadstack(object):
         self._hole_parameters = self._hole_params[2]
         return self._hole_parameters
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _update_hole_parameters(self, hole_type=None, params=None, offsetx=None, offsety=None, rotation=None):
         """Update hole parameters.
 
@@ -1640,15 +1647,19 @@ class EDBPadstack(object):
             rotation = self.hole_rotation
         if is_ironpython:
             newPadstackDefinitionData.SetHoleParameters(
-                hole_type, params, self._edb_value(offsetx), self._edb_value(offsety), self._edb_value(rotation)
+                hole_type,
+                params,
+                self._get_edb_value(offsetx),
+                self._get_edb_value(offsety),
+                self._get_edb_value(rotation),
             )
         else:
             newPadstackDefinitionData.SetHoleParameters(
                 hole_type,
                 convert_py_list_to_net_list(params),
-                self._edb_value(offsetx),
-                self._edb_value(offsety),
-                self._edb_value(rotation),
+                self._get_edb_value(offsetx),
+                self._get_edb_value(offsety),
+                self._get_edb_value(rotation),
             )
         self.edb_padstack.SetData(newPadstackDefinitionData)
 
@@ -1668,9 +1679,9 @@ class EDBPadstack(object):
     def hole_properties(self, propertylist):
 
         if not isinstance(propertylist, list):
-            propertylist = [self._edb_value(propertylist)]
+            propertylist = [self._get_edb_value(propertylist)]
         else:
-            propertylist = [self._edb_value(i) for i in propertylist]
+            propertylist = [self._get_edb_value(i) for i in propertylist]
         self._update_hole_parameters(params=propertylist)
 
     @property
@@ -1755,7 +1766,7 @@ class EDBPadstack(object):
 
         originalPadstackDefinitionData = self.edb_padstack.GetData()
         newPadstackDefinitionData = self._edb.Definition.PadstackDefData(originalPadstackDefinitionData)
-        newPadstackDefinitionData.SetHolePlatingPercentage(self._edb_value(ratio))
+        newPadstackDefinitionData.SetHolePlatingPercentage(self._get_edb_value(ratio))
         self.edb_padstack.SetData(newPadstackDefinitionData)
 
     @property
@@ -1952,7 +1963,7 @@ class EDBPadstackInstance(object):
 
     @property
     def position(self):
-        """padstack instance position.
+        """Padstack instance position.
 
         Returns
         -------
@@ -1972,7 +1983,7 @@ class EDBPadstackInstance(object):
 
     @property
     def rotation(self):
-        """padstack instance rotation.
+        """Padstack instance rotation.
 
         Returns
         -------
@@ -2003,6 +2014,7 @@ class EDBPadstackInstance(object):
 
     @property
     def name(self):
+        """Padstack Instance Name. If it is a pin, the syntax will be like in AEDT ComponentName-PinName."""
         if self.is_pin:
             comp_name = self._edb_padstackinstance.GetComponent().GetName()
             pin_name = self._edb_padstackinstance.GetName()
@@ -2010,12 +2022,12 @@ class EDBPadstackInstance(object):
         else:
             return self._edb_padstackinstance.GetName()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete_padstack_instance(self):
         """Delete this padstack instance."""
         self._edb_padstackinstance.Delete()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def in_voids(self, net_name=None, layer_name=None):
         """Check if this padstack instance is in any void.
 
@@ -2101,6 +2113,149 @@ class EDBPadstackInstance(object):
         """
         return int(self._edb_padstackinstance.GetGroup().GetPlacementLayer().GetTopBottomAssociation())
 
+    @pyaedt_function_handler()
+    def create_rectangle_in_pad(self, layer_name):
+        """Create a rectangle inscribed inside a padstack instance pad. The rectangle is fully inscribed in the
+        pad and has the maximum area. It is necessary to specify the layer on which the rectangle will be created.
+
+        Parameters
+        ----------
+        layer_name : str
+            Name of the layer on which to create the polygon.
+
+        Returns
+        -------
+        bool, :class:`pyaedt.edb_core.EDB_Data.EDBPrimitives`
+            Polygon when successful, ``False`` when failed.
+
+        Examples
+        --------
+        >>> from pyaedt import Edb
+        >>> edbapp = Edb("myaedbfolder", edbversion="2021.2")
+        >>> edb_layout = edbapp.core_primitives
+        >>> list_of_padstack_instances = list(edbapp.core_padstack.padstack_instances.values())
+        >>> padstack_inst = list_of_padstack_instances[0]
+        >>> padstack_inst.create_rectangle_in_pad("TOP")
+        """
+
+        padstack_center = self.position
+        padstack_name = self.padstack_definition
+        try:
+            padstack = self._pedb.core_padstack.padstacks[padstack_name]
+        except KeyError:  # pragma: no cover
+            return False
+        try:
+            padstack_pad = padstack.pad_by_layer[layer_name]
+        except KeyError:  # pragma: no cover
+            return False
+
+        pad_shape = padstack_pad.geometry_type
+        params = padstack_pad.parameters_values
+        polygon_data = padstack_pad.polygon_data
+
+        rect = None
+        pcx = padstack_center[0]
+        pcy = padstack_center[1]
+
+        if pad_shape == 1:
+            # Circle
+            diameter = params[0]
+            r = diameter * 0.5
+            p1 = [pcx + r, pcy]
+            p2 = [pcx, pcy + r]
+            p3 = [pcx - r, pcy]
+            p4 = [pcx, pcy - r]
+            rect = [p1, p2, p3, p4]
+        elif pad_shape == 2:
+            # Square
+            square_size = params[0]
+            s2 = square_size * 0.5
+            p1 = [pcx + s2, pcy + s2]
+            p2 = [pcx - s2, pcy + s2]
+            p3 = [pcx - s2, pcy - s2]
+            p4 = [pcx + s2, pcy - s2]
+            rect = [p1, p2, p3, p4]
+        elif pad_shape == 3:
+            # Rectangle
+            x_size = float(params[0])
+            y_size = float(params[1])
+            sx2 = x_size * 0.5
+            sy2 = y_size * 0.5
+            p1 = [pcx + sx2, pcy + sy2]
+            p2 = [pcx - sx2, pcy + sy2]
+            p3 = [pcx - sx2, pcy - sy2]
+            p4 = [pcx + sx2, pcy - sy2]
+            rect = [p1, p2, p3, p4]
+        elif pad_shape == 4:
+            # Oval
+            x_size = params[0]
+            y_size = params[1]
+            corner_radius = float(params[2])
+            if corner_radius >= min(x_size, y_size):
+                r = min(x_size, y_size)
+            else:
+                r = corner_radius
+            sx = x_size * 0.5 - r
+            sy = y_size * 0.5 - r
+            k = r / math.sqrt(2)
+            p1 = [pcx + sx + k, pcy + sy + k]
+            p2 = [pcx - sx - k, pcy + sy + k]
+            p3 = [pcx - sx - k, pcy - sy - k]
+            p4 = [pcx + sx + k, pcy - sy - k]
+            rect = [p1, p2, p3, p4]
+        elif pad_shape == 5:
+            # Bullet
+            x_size = params[0]
+            y_size = params[1]
+            corner_radius = params[2]
+            if corner_radius >= min(x_size, y_size):
+                r = min(x_size, y_size)
+            else:
+                r = corner_radius
+            sx = x_size * 0.5 - r
+            sy = y_size * 0.5 - r
+            k = r / math.sqrt(2)
+            p1 = [pcx + sx + k, pcy + sy + k]
+            p2 = [pcx - x_size * 0.5, pcy + sy + k]
+            p3 = [pcx - x_size * 0.5, pcy - sy - k]
+            p4 = [pcx + sx + k, pcy - sy - k]
+            rect = [p1, p2, p3, p4]
+        elif pad_shape == 6:
+            # N-Sided Polygon
+            size = params[0]
+            num_sides = params[1]
+            ext_radius = size * 0.5
+            apothem = ext_radius * math.cos(math.pi / num_sides)
+            p1 = [pcx + apothem, pcy]
+            p2 = [pcx, pcy + apothem]
+            p3 = [pcx - apothem, pcy]
+            p4 = [pcx, pcy - apothem]
+            rect = [p1, p2, p3, p4]
+        elif pad_shape == 0 and polygon_data is not None:
+            # Polygon
+            points = []
+            i = 0
+            while i < polygon_data.Count:
+                point = polygon_data.GetPoint(i)
+                if point.IsArc():
+                    continue
+                else:
+                    points.append([point.X.ToDouble(), point.Y.ToDouble()])
+                i += 1
+            xpoly, ypoly = zip(*points)
+            polygon = [list(xpoly), list(ypoly)]
+            rectangles = GeometryOperators.find_largest_rectangle_inside_polygon(polygon)
+            rect = rectangles[0]
+            for i in range(4):
+                rect[i][0] = rect[i][0] + pcx
+                rect[i][1] = rect[i][1] + pcy
+
+        if rect is None or len(rect) != 4:
+            return False
+        path = self._pedb.core_primitives.Shape("polygon", points=rect)
+        created_polygon = self._pedb.core_primitives.create_polygon(path, padstack_pad.layer_name)
+        return created_polygon
+
 
 class EDBComponent(object):
     """Manages EDB functionalities for components.
@@ -2118,6 +2273,25 @@ class EDBComponent(object):
         self._pcomponents = components
         self.edbcomponent = cmp
 
+    @property
+    def component_property(self):
+        """Component Property Object."""
+        return self.edbcomponent.GetComponentProperty().Clone()
+
+    @property
+    def solder_ball_height(self):
+        """Solder ball height if available.."""
+        if "GetSolderBallProperty" in dir(self.component_property):
+            return self.component_property.GetSolderBallProperty().GetHeight()
+        return None
+
+    @property
+    def solder_ball_placement(self):
+        """Solder ball placement if available.."""
+        if "GetSolderBallProperty" in dir(self.component_property):
+            return int(self.component_property.GetSolderBallProperty().GetPlacement())
+        return 2
+
     @property
     def refdes(self):
         """Reference Designator Name.
@@ -2307,9 +2481,8 @@ class EDBComponent(object):
         """
         return self.edbcomponent.GetComponentDef().GetName()
 
-    @property
-    def _edb_value(self):
-        return self._pcomponents._edb_value
+    def _get_edb_value(self, value):
+        return self._pcomponents._get_edb_value(value)
 
     @property
     def _edb(self):
@@ -2324,7 +2497,7 @@ class EDBComponent(object):
         str
            Name of the placement layer.
         """
-        return self.pinlist[0].GetGroup().GetPlacementLayer().GetName()
+        return self.edbcomponent.GetPlacementLayer().GetName()
 
     @property
     def lower_elevation(self):
@@ -2335,7 +2508,7 @@ class EDBComponent(object):
         float
             Lower elevation of the placement layer.
         """
-        return self.pinlist[0].GetGroup().GetPlacementLayer().GetLowerElevation()
+        return self.edbcomponent.GetPlacementLayer().GetLowerElevation()
 
     @property
     def upper_elevation(self):
@@ -2347,7 +2520,7 @@ class EDBComponent(object):
             Upper elevation of the placement layer.
 
         """
-        return self.pinlist[0].GetGroup().GetPlacementLayer().GetUpperElevation()
+        return self.edbcomponent.GetPlacementLayer().GetUpperElevation()
 
     @property
     def top_bottom_association(self):
@@ -2364,7 +2537,7 @@ class EDBComponent(object):
             * 4 - Number of top/bottom associations.
             * -1 - Undefined
         """
-        return int(self.pinlist[0].GetGroup().GetPlacementLayer().GetTopBottomAssociation())
+        return int(self.edbcomponent.GetPlacementLayer().GetTopBottomAssociation())
 
 
 class EdbBuilder(object):
