@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+from __future__ import absolute_import  # noreorder
 
 from pyaedt.application.AnalsyisEmit import FieldAnalysisEmit
 
@@ -33,9 +33,10 @@ class Emit(FieldAnalysisEmit, object):
         Version of AEDT to use. The default is ``None``, in which case
         the active setup is used or the latest installed version is
         used.
-    NG : bool, optional
-        Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical mode.
+    non_graphical : bool, optional
+        Whether to launch AEDT in non-graphical mode. The default
+        is ``False``, in which case AEDT is launched in graphical mode.
+        This parameter is ignored when a script is launched within AEDT.
     new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
