@@ -1,4 +1,5 @@
 import math
+import warnings
 
 RAD2DEG = 180.0 / math.pi
 DEG2RAD = math.pi / 180
@@ -125,6 +126,60 @@ def _resolve_unit_system(unit_system_1, unit_system_2, operation):
         return ""
 
 
+def unit_converter(value, unit_system="Length", input_units="meter", output_units="mm"):
+    """Convert Unit in specified Unit System.
+
+    Parameters
+    ----------
+    value : float
+        Value to convert.
+    unit_system : str
+        Unit system. Default is `"Length"`.
+    input_units : str
+        Input units. Default is `"meter"`.
+    output_units : str
+        Output units. Default is `"mm"`.
+
+    Returns
+    -------
+    float
+        Converted value.
+    """
+    if unit_system in AEDT_UNITS:
+        if input_units not in AEDT_UNITS[unit_system] or output_units not in AEDT_UNITS[unit_system]:
+            warnings.warn("No units found")
+            return value
+        else:
+            return value * AEDT_UNITS[unit_system][input_units] / AEDT_UNITS[unit_system][output_units]
+    warnings.warn("No system unit found")
+    return value
+
+
+def scale_units(scale_to_unit):
+    """Find the scale_to_unit into main system unit.
+
+    Parameters
+    ----------
+    scale_to_unit : str
+        Unit to Scale.
+
+    Returns
+    -------
+    float
+        Return the scaling factor if any.
+    """
+    sunit = 1.0
+    for val in list(AEDT_UNITS.values()):
+        for unit, scale_val in val.items():
+            if scale_to_unit.lower() == unit.lower():
+                sunit = scale_val
+                break
+        else:
+            continue
+        break
+    return sunit
+
+
 AEDT_UNITS = {
     "AngularSpeed": {
         "deg_per_hr": HOUR2SEC * DEG2RAD,
@@ -176,6 +231,7 @@ AEDT_UNITS = {
         "cm": 1e-2,
         "dm": 1e-1,
         "meter": 1.0,
+        "meters": 1.0,
         "km": 1e3,
         "uin": METER2IN * 1e-6,
         "mil": METER2IN * 1e-3,
