@@ -1,9 +1,13 @@
-import warnings
 import os
+import re
+import warnings
 
-from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name
-from pyaedt.modeler.PrimitivesCircuit import CircuitComponents, ComponentCatalog
+from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import pyaedt_function_handler
+from pyaedt.generic.LoadAEDTFile import load_entire_aedt_file
 from pyaedt.modeler.Object3d import CircuitComponent
+from pyaedt.modeler.PrimitivesCircuit import CircuitComponents
+from pyaedt.modeler.PrimitivesCircuit import ComponentCatalog
 
 
 class NexximComponents(CircuitComponents):
@@ -31,7 +35,7 @@ class NexximComponents(CircuitComponents):
         """Tab name."""
         return "PassedParameterTab"
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def __getitem__(self, partname):
         """Get the object ID if the part name is an integer or the object name if it is a string.
         Parameters
@@ -75,7 +79,7 @@ class NexximComponents(CircuitComponents):
             self._components_catalog = ComponentCatalog(self)
         return self._components_catalog
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def connect_components_in_series(self, components_to_connect):
         """Connect schematic components in series.
 
@@ -113,7 +117,7 @@ class NexximComponents(CircuitComponents):
             i += 1
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def connect_components_in_parallel(self, components_to_connect):
         """Connect schematic components in parallel.
 
@@ -151,7 +155,7 @@ class NexximComponents(CircuitComponents):
             terminal_to_connect[0].pins[1].connect_to_component([i.pins[1] for i in terminal_to_connect[1:]])
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_3dlayout_subcircuit(self, sourcename):
         """Add a subcircuit from a HFSS 3DLayout.
 
@@ -163,7 +167,7 @@ class NexximComponents(CircuitComponents):
         )
         return self.add_subcircuit_3dlayout(sourcename)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_subcircuit_3dlayout(self, sourcename):
         """Add a subcircuit from a HFSS 3DLayout.
 
@@ -193,7 +197,7 @@ class NexximComponents(CircuitComponents):
                 return self.components[el]
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_field_model(self, design_name, solution_name, pin_names, model_type="hfss", posx=0, posy=1):
         """Create a field model.
 
@@ -449,7 +453,7 @@ class NexximComponents(CircuitComponents):
                 return el, self.components[el].composed_name
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_resistor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create a resistor.
 
@@ -484,7 +488,7 @@ class NexximComponents(CircuitComponents):
         cmpid.set_property("R", value)
         return cmpid
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_inductor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create an inductor.
 
@@ -525,7 +529,7 @@ class NexximComponents(CircuitComponents):
 
         return cmpid
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_capacitor(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create a capacitor.
 
@@ -565,7 +569,7 @@ class NexximComponents(CircuitComponents):
         cmpid.set_property("C", value)
         return cmpid
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_voltage_dc(self, compname=None, value=1, location=[], angle=0, use_instance_id_netlist=False):
         """Create a voltage DC source.
 
@@ -605,7 +609,7 @@ class NexximComponents(CircuitComponents):
         cmpid.set_property("DC", value)
         return cmpid
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_current_pulse(self, compname=None, value_lists=[], location=[], angle=0, use_instance_id_netlist=False):
         """Create a current pulse.
 
@@ -659,7 +663,7 @@ class NexximComponents(CircuitComponents):
 
         return cmpid
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_voltage_pulse(self, compname=None, value_lists=[], location=[], angle=0, use_instance_id_netlist=False):
         """Create a voltage pulse.
 
@@ -713,7 +717,7 @@ class NexximComponents(CircuitComponents):
 
         return cmpid
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_current_dc(self, compname=None, value=1, location=[], angle=0, use_instance_id_netlist=False):
         """Create a current DC source.
 
@@ -798,7 +802,7 @@ class NexximComponents(CircuitComponents):
         cmpid.set_property("CouplingFactor", value)
         return cmpid
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_diode(self, compname=None, model_name="required", location=[], angle=0, use_instance_id_netlist=False):
         """Create a diode.
 
@@ -838,7 +842,7 @@ class NexximComponents(CircuitComponents):
         cmpid.set_property("MOD", model_name)
         return cmpid
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_npn(self, compname=None, value=None, location=[], angle=0, use_instance_id_netlist=False):
         """Create an NPN transistor.
 
@@ -878,7 +882,7 @@ class NexximComponents(CircuitComponents):
             id.set_property("MOD", value)
         return id
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_pnp(self, compname=None, value=50, location=[], angle=0, use_instance_id_netlist=False):
         """Create a PNP transistor.
 
@@ -919,9 +923,17 @@ class NexximComponents(CircuitComponents):
 
         return id
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_new_component_from_symbol(
-        self, symbol_name, pin_lists, Refbase="U", parameter_list=[], parameter_value=[]
+        self,
+        symbol_name,
+        pin_lists,
+        time_stamp=1591858313,
+        description="",
+        refbase="x",
+        parameter_list=[],
+        parameter_value=[],
+        gref="",
     ):
         """Create a component from a symbol.
 
@@ -931,12 +943,18 @@ class NexximComponents(CircuitComponents):
             Name of the symbol.
         pin_lists : list
             List of pin names.
-        Refbase : str, optional
+        time_stamp : int, optional
+            UTC time stamp.
+        description : str, optional
+            Component description.
+        refbase : str, optional
             Reference base. The default is ``"U"``.
         parameter_list : list
             List of parameters. The default is ``[]``.
         parameter_value : list
             List of parameter values. The default is ``[]``.
+        gref : str, optional
+            Global Reference
 
         Returns
         -------
@@ -960,7 +978,7 @@ class NexximComponents(CircuitComponents):
                 "DataSource:=",
                 "",
                 "ModifiedOn:=",
-                1591858313,
+                time_stamp,
                 "Manufacturer:=",
                 "",
                 "Symbol:=",
@@ -970,7 +988,7 @@ class NexximComponents(CircuitComponents):
                 "Footprint:=",
                 "",
                 "Description:=",
-                "",
+                description,
                 "InfoTopic:=",
                 "",
                 "InfoHelpFile:=",
@@ -988,7 +1006,7 @@ class NexximComponents(CircuitComponents):
                 "OriginalAuthor:=",
                 "",
                 "CreationDate:=",
-                1591858278,
+                time_stamp,
                 "ExampleFile:=",
                 "",
                 "HiddenComponent:=",
@@ -1001,7 +1019,7 @@ class NexximComponents(CircuitComponents):
             "CircuitEnv:=",
             0,
             "Refbase:=",
-            Refbase,
+            refbase,
             "NumParts:=",
             1,
             "ModSinceLib:=",
@@ -1014,29 +1032,32 @@ class NexximComponents(CircuitComponents):
         arg.append("CompExtID:=")
         arg.append(1)
         arg2 = ["NAME:Parameters"]
+
         for el, val in zip(parameter_list, parameter_value):
-            if type(val) is str:
+            if "MOD" in el:
                 arg2.append("TextValueProp:=")
                 arg2.append([el, "D", "", val])
             else:
-                arg2.append("ValueProp:=")
-                arg2.append([el, "D", "", val, False, ""])
+                arg2.append("ValuePropNU:=")
+                arg2.append([el, "D", "", str(val), 0, ""])
+
         arg2.append("ButtonProp:=")
         arg2.append(["CosimDefinition", "D", "", "Edit", "Edit", 40501, "ButtonPropClientData:=", []])
         arg2.append("MenuProp:=")
         arg2.append(["CoSimulator", "D", "", "DefaultNetlist", 0])
 
         arg.append(arg2)
-        spicesintax = Refbase + "@ID "
+        spicesintax = refbase + "@ID "
         id = 0
         while id < len(pin_lists):
             spicesintax += "%" + str(id) + " "
             id += 1
+        # spicesintax += symbol_name + " "
         for el, val in zip(parameter_list, parameter_value):
             if "MOD" in el:
                 spicesintax += "@{} ".format(el)
             else:
-                spicesintax += "{}=@{} ".format(el, val)
+                spicesintax += "{}=@{} ".format(el, el)
 
         arg3 = [
             "NAME:CosimDefinitions",
@@ -1053,16 +1074,17 @@ class NexximComponents(CircuitComponents):
                 "Data:=",
                 ["Nexxim Circuit:=", spicesintax],
                 "GRef:=",
-                ["Nexxim Circuit:=", ""],
+                ["Nexxim Circuit:=", gref],
             ],
             "DefaultCosim:=",
             "DefaultNetlist",
         ]
         arg.append(arg3)
+        print(arg)
         self.o_component_manager.Add(arg)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_comp_custom_settings(
         self, toolNum, dc=0, interp=0, extrap=1, conv=0, passivity=0, reciprocal="False", opt="", data_type=1
     ):
@@ -1124,7 +1146,7 @@ class NexximComponents(CircuitComponents):
 
         return res
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_subcircuit_hfss_link(
         self,
         comp_name,
@@ -1186,7 +1208,7 @@ class NexximComponents(CircuitComponents):
             variables=variables,
         )
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_subcircuit_dynamic_link(
         self,
         pyaedt_app=None,
@@ -1206,7 +1228,7 @@ class NexximComponents(CircuitComponents):
         solution_name : str, optional
             Name of the solution and sweep. The default is ``"Setup1 : Sweep"``.
         extrusion_length : float, str, optional
-            Extrusion length for 2D Models (q2d or Hfss). Default is `None`.
+            Extrusion length for 2D Models (q2d or Hfss) in model units. Default is `None`.
         enable_cable_modeling : bool, optional
             Either if the Hfss Cable modeling has to be enabled for 2D subcircuits.
         default_matrix : str, optional
@@ -1233,78 +1255,76 @@ class NexximComponents(CircuitComponents):
             comp_name = generate_unique_name(pyaedt_app.design_name)
         source_project_path = pyaedt_app.project_file
         source_design_name = pyaedt_app.design_name
-        matrix = None
-        if pyaedt_app.design_type == "HFSS":
-            pin_names = pyaedt_app.get_excitations_name()
-        elif pyaedt_app.design_type == "Q3D Extractor":
-            excts = list(pyaedt_app.oboundary.GetExcitations())
-            i = 0
-            sources = []
-            sinks = []
-            while i < len(excts):
-                if excts[i + 1] == "Source":
-                    sources.append(excts[i])
-                elif excts[i + 1] == "Sink":
-                    sinks.append(excts[i])
-                i += 2
-            pin_names = sources + sinks
-            matrix = ["NAME:Reduce Matrix Choices"] + list(pyaedt_app.omatrix.ListReduceMatrixes())
-        elif pyaedt_app.design_type == "2D Extractor":
-            excts = list(pyaedt_app.oboundary.GetExcitations())
-            pins = []
-            i = 0
-            while i < len(excts):
-                if excts[i + 1] != "ReferenceGround":
-                    pins.append(excts[i])
-                i += 2
-            pin_names = [i + "_in" for i in pins]
-            pin_names.append("Input_ref")
-            pin_names.extend([i + "_out" for i in pins])
-            pin_names.append("Output_ref")
-            matrix = ["NAME:Reduce Matrix Choices"] + list(pyaedt_app.omatrix.ListReduceMatrixes())
-        variables = {}
-        for k, v in pyaedt_app.variable_manager.variables.items():
-            variables[k] = v.string_value
+        # matrix = None
+        # if pyaedt_app.design_type == "HFSS":
+        #     pin_names = pyaedt_app.get_excitations_name()
+        # elif pyaedt_app.design_type == "Q3D Extractor":
+        #     excts = list(pyaedt_app.oboundary.GetExcitations())
+        #     i = 0
+        #     sources = []
+        #     sinks = []
+        #     while i < len(excts):
+        #         if excts[i + 1] == "Source":
+        #             sources.append(excts[i])
+        #         elif excts[i + 1] == "Sink":
+        #             sinks.append(excts[i])
+        #         i += 2
+        #     pin_names = sources + sinks
+        #     matrix = ["NAME:Reduce Matrix Choices"] + list(pyaedt_app.omatrix.ListReduceMatrixes())
+        # elif pyaedt_app.design_type == "2D Extractor":
+        #     excts = list(pyaedt_app.oboundary.GetExcitations())
+        #     pins = []
+        #     i = 0
+        #     while i < len(excts):
+        #         if excts[i + 1] != "ReferenceGround":
+        #             pins.append(excts[i])
+        #         i += 2
+        #     pin_names = [i + "_in" for i in pins]
+        #     pin_names.append("Input_ref")
+        #     pin_names.extend([i + "_out" for i in pins])
+        #     pin_names.append("Output_ref")
+        #     matrix = ["NAME:Reduce Matrix Choices"] + list(pyaedt_app.omatrix.ListReduceMatrixes())
+        # variables = {}
+        # for k, v in pyaedt_app.variable_manager.variables.items():
+        #     variables[k] = v.string_value
         if not solution_name:
             solution_name = pyaedt_app.nominal_sweep
-        comp = self._add_subcircuit_link(
-            comp_name=comp_name,
-            pin_names=pin_names,
-            source_project_path=source_project_path,
-            source_design_name=source_design_name,
-            solution_name=solution_name,
-            image_subcircuit_path="",
-            model_type=pyaedt_app.design_type,
-            variables=variables,
-            extrusion_length_q2d=extrusion_length,
-            matrix=matrix,
-            enable_cable_modeling=enable_cable_modeling,
-            default_matrix=default_matrix,
-        )
-
-        #
-        #
-        # self._app.odesign.AddDynamicLink(
-        #     source_design_name,
-        #     source_project_path,
-        #     comp_name,
-        #     solution_name,
-        #     tline_port,
-        #     default_matrix,
-        #     enable_cable_modeling,
-        #     "Pyaedt Dynamic Link",
+        # comp = self._add_subcircuit_link(
+        #     comp_name=comp_name,
+        #     pin_names=pin_names,
+        #     source_project_path=source_project_path,
+        #     source_design_name=source_design_name,
+        #     solution_name=solution_name,
+        #     image_subcircuit_path="",
+        #     model_type=pyaedt_app.design_type,
+        #     variables=variables,
+        #     extrusion_length_q2d=extrusion_length,
+        #     matrix=matrix,
+        #     enable_cable_modeling=enable_cable_modeling,
+        #     default_matrix=default_matrix,
         # )
+
+        self._app.odesign.AddDynamicLink(
+            source_design_name,
+            source_project_path,
+            comp_name,
+            solution_name,
+            tline_port,
+            default_matrix,
+            enable_cable_modeling,
+            "Pyaedt Dynamic Link",
+        )
         self.refresh_all_ids()
         for el in self.components:
             if comp_name in self.components[el].composed_name:
                 if extrusion_length:
-                    self.components[el].set_property("Length", extrusion_length)
+                    self.components[el].set_property("Length", self.arg_with_dim(extrusion_length))
                 if tline_port and extrusion_length:
-                    self.components[el].set_property("TLineLength", extrusion_length)
+                    self.components[el].set_property("TLineLength", self.arg_with_dim(extrusion_length))
                 return self.components[el]
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _add_subcircuit_link(
         self,
         comp_name,
@@ -1319,6 +1339,7 @@ class NexximComponents(CircuitComponents):
         matrix=None,
         enable_cable_modeling=False,
         default_matrix="Original",
+        simulate_solutions=False,
     ):
         """Add a subcircuit HFSS link.
 
@@ -1345,6 +1366,8 @@ class NexximComponents(CircuitComponents):
         extrusion_length_q2d : str, float optional
             Extrusion length for 2D Models. Default is 10 (in model units).
         matrix : list, optional
+        simulate_solutions : bool, optional
+            Either if simulate or interpolate solutions.
 
         Returns
         -------
@@ -1370,6 +1393,10 @@ class NexximComponents(CircuitComponents):
             model = "2dext"
             owner = "2DExtractor"
             icon_file = "2dextractor.bmp"
+        elif model_type.lower() == "siwave":
+            model = "siwave"
+            owner = "Siwave"
+            icon_file = ""
         designer_customization = self.get_comp_custom_settings(1, 0, 0, 1, 0, 0, "False", "", 1)
         nexxim_customization = self.get_comp_custom_settings(2, 3, 1, 3, 0, 0, "False", "", 2)
         hspice_customization = self.get_comp_custom_settings(3, 1, 2, 3, 0, 0, "False", "", 3)
@@ -1435,9 +1462,9 @@ class NexximComponents(CircuitComponents):
             "numberofports:=",
             len(pin_names),
             "Simulate:=",
-            False,
+            simulate_solutions,
             "CloseProject:=",
-            False,
+            model_type.lower() == "siwave",
             "SaveProject:=",
             True,
             "InterpY:=",
@@ -1447,7 +1474,7 @@ class NexximComponents(CircuitComponents):
             "IgnoreDepVars:=",
             False,
         ]
-        if owner == "HFSS":
+        if owner in ["HFSS", "Siwave"]:
             compInfo.extend(
                 [
                     "Renormalize:=",
@@ -1598,7 +1625,7 @@ class NexximComponents(CircuitComponents):
                 return self.components[el]
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def set_sim_option_on_hfss_subcircuit(self, component, option="simulate"):
         """Set the simulation option on the HFSS subscircuit.
 
@@ -1629,7 +1656,7 @@ class NexximComponents(CircuitComponents):
         arg = ["NAME:Simulation option", "Value:=", setting]
         return self._edit_link_definition_hfss_subcircuit(component, arg)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def set_sim_solution_on_hfss_subcircuit(self, component, solution_name="Setup1 : Sweep"):
         """Set the simulation solution on the HFSS subcircuit.
 
@@ -1653,7 +1680,7 @@ class NexximComponents(CircuitComponents):
         arg = ["NAME:Solution", "Value:=", solution_name]
         return self._edit_link_definition_hfss_subcircuit(component, arg)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _edit_link_definition_hfss_subcircuit(self, component, edited_prop):
         """Generic function to set the link definition for an hfss subcircuit."""
         if isinstance(component, str):
@@ -1677,7 +1704,7 @@ class NexximComponents(CircuitComponents):
         self._app._oproject.ChangeProperty(arg)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def refresh_dynamic_link(self, component_name):
         """Refresh a dynamic link.
 
@@ -1703,7 +1730,7 @@ class NexximComponents(CircuitComponents):
         self.o_component_manager.UpdateDynamicLink(component_name)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def push_excitations(self, instance_name, thevenin_calculation=False, setup_name="LinearFrequency"):
         """Push excitations.
 
@@ -1716,7 +1743,7 @@ class NexximComponents(CircuitComponents):
         )
         return self._app.push_excitations(instance_name, thevenin_calculation, setup_name)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_sin_excitation2ports(self, ports, settings):
         """Assign a voltage sinusoidal excitation to circuit ports.
 
@@ -1729,3 +1756,103 @@ class NexximComponents(CircuitComponents):
             DeprecationWarning,
         )
         return self._app.assign_voltage_sinusoidal_excitation_to_ports(ports, settings)
+
+    @pyaedt_function_handler()
+    def _parse_spice_model(self, model_path):
+        models = []
+        with open(model_path, "r") as f:
+            for line in f:
+                if ".subckt" in line.lower():
+                    pinNames = [i.strip() for i in re.split(" |\t", line) if i]
+                    models.append(pinNames[1])
+        return models
+
+    @pyaedt_function_handler()
+    def create_component_from_spicemodel(self, model_path, model_name=None, location=None):
+        """Create and place a new component based on a spice .lib file.
+
+        Parameters
+        ----------
+        model_path : str
+            Path to .lib file.
+        model_name : str, optional
+            Model name to import. If `None` the first subckt in the lib file will be placed.
+        location : list, optional
+            Position in the schematic of the new component.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
+        """
+        models = self._parse_spice_model(model_path)
+        if not model_name and models:
+            model_name = models[0]
+        elif model_name not in models:
+            return False
+        arg = ["NAME:Options", "Mode:=", 2, "Overwrite:=", False, "SupportsSimModels:=", False, "LoadOnly:=", False]
+        arg2 = ["NAME:Models"]
+        for el in models:
+            arg2.append(el + ":=")
+            if el == model_name:
+                arg2.append([True, "", "", False])
+            else:
+                arg2.append([False, "", "", False])
+        arg.append(arg2)
+        self.o_component_manager.ImportModelsFromFile(model_path, arg)
+
+        return self.create_component(
+            None,
+            component_library=None,
+            component_name=model_name,
+            location=location,
+        )
+
+    @pyaedt_function_handler()
+    def add_siwave_dynamic_link(self, model_path, solution_name=None, simulate_solutions=False):
+        """Add a siwave dinamyc link object.
+
+        Parameters
+        ----------
+        model_path : str
+            Full path to the .siw file.
+        solution_name : str, optional
+            Solution name.
+        simulate_solutions : bool, optional
+            Either if simulate or interpolate existing solutions.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object.
+        """
+        assert os.path.exists(model_path), "Project file doesn't exist"
+        comp_name = os.path.splitext(os.path.basename(model_path))[0]
+        results_path = model_path + "averesults"
+        solution = os.path.join(results_path, comp_name + ".asol")
+        out = load_entire_aedt_file(solution)
+        if not solution_name:
+            solution_name = list(out["Solutions"]["SYZSolutions"].keys())[0]
+        results_folder = os.path.join(
+            results_path,
+            out["Solutions"]["SYZSolutions"][solution_name]["DiskName"],
+            out["Solutions"]["SYZSolutions"][solution_name]["DiskName"] + ".syzinfo",
+        )
+
+        pin_names = []
+        with open(results_folder, "r") as f:
+            lines = f.read().splitlines()
+            for line in lines:
+                if line[:4] == "PORT":
+                    line_spit = line.split(" ")
+                    pin_names.append(line_spit[1])
+
+        return self._add_subcircuit_link(
+            comp_name,
+            pin_names,
+            model_path,
+            comp_name,
+            solution_name=solution_name,
+            model_type="siwave",
+            simulate_solutions=simulate_solutions,
+        )
