@@ -3,18 +3,49 @@ This module contains these classes: `BoundaryCommon` and `BoundaryObject`.
 """
 from collections import OrderedDict
 
-from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name, filter_tuple
-from pyaedt.generic.DataHandlers import _dict2arg
-from pyaedt.modeler.Object3d import EdgePrimitive, FacePrimitive, VertexPrimitive
-from pyaedt.generic.DataHandlers import random_string
-from pyaedt.modeler.Object3d import _dim_arg
 from pyaedt.generic.constants import CATEGORIESQ3D
+from pyaedt.generic.DataHandlers import _dict2arg
+from pyaedt.generic.DataHandlers import random_string
+from pyaedt.generic.general_methods import filter_tuple
+from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import pyaedt_function_handler
+from pyaedt.modeler.Object3d import _dim_arg
+from pyaedt.modeler.Object3d import EdgePrimitive
+from pyaedt.modeler.Object3d import FacePrimitive
+from pyaedt.modeler.Object3d import VertexPrimitive
+
+
+class BoundaryProps(OrderedDict):
+    """AEDT Boundary Component Internal Parameters."""
+
+    def __setitem__(self, key, value):
+        OrderedDict.__setitem__(self, key, value)
+        if self._pyaedt_boundary.auto_update:
+            if key in ["Edges", "Faces", "Objects"]:
+                res = self._pyaedt_boundary.update_assignment()
+            else:
+                res = self._pyaedt_boundary.update()
+            if not res:
+                self._pyaedt_boundary._app.logger.warning("Update of %s Failed. Check needed arguments", key)
+
+    def __init__(self, boundary, props):
+        OrderedDict.__init__(self)
+        if props:
+            for key, value in props.items():
+                if isinstance(value, (OrderedDict, OrderedDict)):
+                    OrderedDict.__setitem__(self, key, BoundaryProps(boundary, value))
+                else:
+                    OrderedDict.__setitem__(self, key, value)
+        self._pyaedt_boundary = boundary
+
+    def _setitem_without_update(self, key, value):
+        OrderedDict.__setitem__(self, key, value)
 
 
 class BoundaryCommon(object):
     """ """
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _get_args(self, props=None):
         """Retrieve boundary properties.
 
@@ -35,7 +66,7 @@ class BoundaryCommon(object):
         _dict2arg(props, arg)
         return arg
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete(self):
         """Delete the boundary.
 
@@ -68,50 +99,55 @@ class NativeComponentObject(BoundaryCommon, object):
     """
 
     def __init__(self, app, component_type, component_name, props):
+        self.auto_update = False
         self._app = app
         self.name = "InsertNativeComponentData"
         self.component_name = component_name
-        self.props = OrderedDict(
-            {
-                "TargetCS": "Global",
-                "SubmodelDefinitionName": self.component_name,
-                "ComponentPriorityLists": OrderedDict({}),
-                "NextUniqueID": 0,
-                "MoveBackwards": False,
-                "DatasetType": "ComponentDatasetType",
-                "DatasetDefinitions": OrderedDict({}),
-                "BasicComponentInfo": OrderedDict(
-                    {
-                        "ComponentName": self.component_name,
-                        "Company": "",
-                        "Company URL": "",
-                        "Model Number": "",
-                        "Help URL": "",
-                        "Version": "1.0",
-                        "Notes": "",
-                        "IconType": "",
-                    }
-                ),
-                "GeometryDefinitionParameters": OrderedDict({"VariableOrders": OrderedDict({})}),
-                "DesignDefinitionParameters": OrderedDict({"VariableOrders": OrderedDict({})}),
-                "MaterialDefinitionParameters": OrderedDict({"VariableOrders": OrderedDict({})}),
-                "MapInstanceParameters": "DesignVariable",
-                "UniqueDefinitionIdentifier": "89d26167-fb77-480e-a7ab-"
-                + random_string(12, char_set="abcdef0123456789"),
-                "OriginFilePath": "",
-                "IsLocal": False,
-                "ChecksumString": "",
-                "ChecksumHistory": [],
-                "VersionHistory": [],
-                "NativeComponentDefinitionProvider": OrderedDict({"Type": component_type}),
-                "InstanceParameters": OrderedDict(
-                    {"GeometryParameters": "", "MaterialParameters": "", "DesignParameters": ""}
-                ),
-            }
+        self.props = BoundaryProps(
+            self,
+            OrderedDict(
+                {
+                    "TargetCS": "Global",
+                    "SubmodelDefinitionName": self.component_name,
+                    "ComponentPriorityLists": OrderedDict({}),
+                    "NextUniqueID": 0,
+                    "MoveBackwards": False,
+                    "DatasetType": "ComponentDatasetType",
+                    "DatasetDefinitions": OrderedDict({}),
+                    "BasicComponentInfo": OrderedDict(
+                        {
+                            "ComponentName": self.component_name,
+                            "Company": "",
+                            "Company URL": "",
+                            "Model Number": "",
+                            "Help URL": "",
+                            "Version": "1.0",
+                            "Notes": "",
+                            "IconType": "",
+                        }
+                    ),
+                    "GeometryDefinitionParameters": OrderedDict({"VariableOrders": OrderedDict({})}),
+                    "DesignDefinitionParameters": OrderedDict({"VariableOrders": OrderedDict({})}),
+                    "MaterialDefinitionParameters": OrderedDict({"VariableOrders": OrderedDict({})}),
+                    "MapInstanceParameters": "DesignVariable",
+                    "UniqueDefinitionIdentifier": "89d26167-fb77-480e-a7ab-"
+                    + random_string(12, char_set="abcdef0123456789"),
+                    "OriginFilePath": "",
+                    "IsLocal": False,
+                    "ChecksumString": "",
+                    "ChecksumHistory": [],
+                    "VersionHistory": [],
+                    "NativeComponentDefinitionProvider": OrderedDict({"Type": component_type}),
+                    "InstanceParameters": OrderedDict(
+                        {"GeometryParameters": "", "MaterialParameters": "", "DesignParameters": ""}
+                    ),
+                }
+            ),
         )
         if props:
             self._update_props(self.props, props)
         self.native_properties = self.props["NativeComponentDefinitionProvider"]
+        self.auto_update = True
 
     @property
     def targetcs(self):
@@ -141,7 +177,7 @@ class NativeComponentObject(BoundaryCommon, object):
                 d[k] = v
         return d
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _get_args(self, props=None):
         if props is None:
             props = self.props
@@ -149,7 +185,7 @@ class NativeComponentObject(BoundaryCommon, object):
         _dict2arg(props, arg)
         return arg
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create(self):
         """Create a Native Component in AEDT.
 
@@ -172,7 +208,7 @@ class NativeComponentObject(BoundaryCommon, object):
             self.excitation_name = self.antennaname
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def update(self):
         """Update the Native Component in AEDT.
 
@@ -205,7 +241,7 @@ class NativeComponentObject(BoundaryCommon, object):
 
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete(self):
         """Delete the Native Component in AEDT.
 
@@ -240,13 +276,25 @@ class BoundaryObject(BoundaryCommon, object):
     """
 
     def __init__(self, app, name, props, boundarytype):
+        self.auto_update = False
         self._app = app
-        self.name = name
-        self.props = props
+        self._name = name
+        self.props = BoundaryProps(self, OrderedDict(props))
         self.type = boundarytype
         self._boundary_name = self.name
+        self.auto_update = True
 
-    @aedt_exception_handler
+    @property
+    def name(self):
+        """Boundary Name."""
+        return self._name
+
+    @name.setter
+    def name(self, value):
+        self._name = value
+        self.update()
+
+    @pyaedt_function_handler()
     def _get_args(self, props=None):
         """Retrieve arguments.
 
@@ -267,7 +315,7 @@ class BoundaryObject(BoundaryCommon, object):
         _dict2arg(props, arg)
         return arg
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create(self):
         """Create a boundary.
 
@@ -411,7 +459,7 @@ class BoundaryObject(BoundaryCommon, object):
             return False
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def update(self):
         """Update the boundary.
 
@@ -429,7 +477,7 @@ class BoundaryObject(BoundaryCommon, object):
             self._app.oboundary.EditAperture(self._boundary_name, self._get_args())
         elif self.type == "Radiation":
             self._app.oboundary.EditRadiation(self._boundary_name, self._get_args())
-        elif self.type == "FiniteCond":
+        elif self.type in ["FiniteCond", "Finite Conductivity"]:
             self._app.oboundary.EditFiniteCond(self._boundary_name, self._get_args())
         elif self.type == "LumpedRLC":
             self._app.oboundary.EditLumpedRLC(self._boundary_name, self._get_args())
@@ -530,7 +578,7 @@ class BoundaryObject(BoundaryCommon, object):
         self._boundary_name = self.name
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def update_assignment(self):
         """Update the boundary assignment.
 
@@ -573,24 +621,14 @@ class FieldSetup(BoundaryCommon, object):
     """
 
     def __init__(self, app, component_name, props, component_type):
+        self.auto_update = False
         self._app = app
         self.type = component_type
         self.name = component_name
-        self.props = OrderedDict({})
-        if props:
-            self._load_props(self.props, props)
+        self.props = BoundaryProps(self, OrderedDict(props))
+        self.auto_update = True
 
-    def _load_props(self, d, u):
-        for k, v in u.items():
-            if isinstance(v, (dict, OrderedDict)):
-                if k not in d:
-                    d[k] = OrderedDict({})
-                d[k] = self._load_props(d[k], v)
-            else:
-                d[k] = v
-        return d
-
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _get_args(self, props=None):
         if props is None:
             props = self.props
@@ -598,7 +636,7 @@ class FieldSetup(BoundaryCommon, object):
         _dict2arg(props, arg)
         return arg
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create(self):
         """Create a Field Setup Component in HFSS.
 
@@ -625,7 +663,7 @@ class FieldSetup(BoundaryCommon, object):
             self._app.oradfield.AddRadFieldSourceGroup(self._get_args())
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def update(self):
         """Update the Field Setup in AEDT.
 
@@ -652,7 +690,7 @@ class FieldSetup(BoundaryCommon, object):
             self._app.oradfield.EditRadFieldSourceGroup(self._get_args())
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete(self):
         """Delete the Field Setup in AEDT.
 
@@ -1025,7 +1063,7 @@ class Matrix(object):
                 self._operations = [operations]
         self.CATEGORIES = CATEGORIESQ3D()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def sources(self, is_gc_sources=True):
         """List of matrix sources.
 
@@ -1045,7 +1083,7 @@ class Matrix(object):
                 self._sources = list(self._app.omatrix.ListReduceMatrixReducedSources(self.name))
         return self._sources
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def get_sources_for_plot(
         self,
         get_self_terms=True,
@@ -1115,7 +1153,7 @@ class Matrix(object):
             self._operations = self._app.omatrix.ListReduceMatrixOperations(self.name)
         return self._operations
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create(self, source_names=None):
         """Create a new matrix.
 
@@ -1135,7 +1173,7 @@ class Matrix(object):
         self.omatrix.InsertRM(self.name, command)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def delete(self):
         """Delete current matrix.
 
@@ -1150,7 +1188,7 @@ class Matrix(object):
                 self._app.matrices.remove(el)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_operation(self, operation_type, source_names=None):
         """Add a new operation to existing matrix.
 
@@ -1173,7 +1211,7 @@ class Matrix(object):
         self.omatrix.RMAddOp(self.name, command)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _write_command(self, source_names):
         command = ""
         if self._operations[-1] == "JoinSeries":
