@@ -1,7 +1,11 @@
-from collections import OrderedDict
-from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name
-from pyaedt.generic.DataHandlers import _dict2arg, _arg2dict
 import copy
+from collections import OrderedDict
+
+from pyaedt.generic.DataHandlers import _arg2dict
+from pyaedt.generic.DataHandlers import _dict2arg
+from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import pyaedt_function_handler
+from pyaedt.modules.SetupTemplates import SetupProps
 
 defaultparametricSetup = OrderedDict(
     {
@@ -148,6 +152,7 @@ class CommonOptimetrics(object):
     """
 
     def __init__(self, p_app, name, dictinputs, optimtype):
+        self.auto_update = False
         self._app = p_app
         self.omodule = self._app.ooptimetrics
         self.name = name
@@ -156,17 +161,17 @@ class CommonOptimetrics(object):
         inputd = copy.deepcopy(dictinputs)
 
         if optimtype == "OptiParametric":
-            self.props = inputd or copy.deepcopy(defaultparametricSetup)
+            self.props = SetupProps(self, inputd or copy.deepcopy(defaultparametricSetup))
         if optimtype == "OptiDesignExplorer":
-            self.props = inputd or copy.deepcopy(defaultdxSetup)
+            self.props = SetupProps(self, inputd or copy.deepcopy(defaultdxSetup))
         if optimtype == "OptiOptimization":
-            self.props = inputd or copy.deepcopy(defaultoptiSetup)
+            self.props = SetupProps(self, inputd or copy.deepcopy(defaultoptiSetup))
         if optimtype == "OptiSensitivity":
-            self.props = inputd or copy.deepcopy(defaultsensitivitySetup)
+            self.props = SetupProps(self, inputd or copy.deepcopy(defaultsensitivitySetup))
         if optimtype == "OptiStatistical":
-            self.props = inputd or copy.deepcopy(defaultstatisticalSetup)
+            self.props = SetupProps(self, inputd or copy.deepcopy(defaultstatisticalSetup))
         if optimtype == "OptiDXDOE":
-            self.props = inputd or copy.deepcopy(defaultdoeSetup)
+            self.props = SetupProps(self, inputd or copy.deepcopy(defaultdoeSetup))
 
         if inputd:
             self.props.pop("ID", None)
@@ -198,8 +203,9 @@ class CommonOptimetrics(object):
                     arg1 = OrderedDict()
                     _arg2dict(calculation, arg1)
                     self.props["Goals"] = arg1
+        self.auto_update = True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def update(self, update_dictionary=None):
         """Update the setup based on stored properties.
 
@@ -220,7 +226,7 @@ class CommonOptimetrics(object):
         """
         if update_dictionary:
             for el in update_dictionary:
-                self.props[el] = update_dictionary[el]
+                self.props._setitem_without_update(el, update_dictionary[el])
 
         arg = ["NAME:" + self.name]
         _dict2arg(self.props, arg)
@@ -228,7 +234,7 @@ class CommonOptimetrics(object):
         self.omodule.EditSetup(self.name, arg)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create(self):
         """Create a setup.
 
@@ -247,7 +253,7 @@ class CommonOptimetrics(object):
         self.omodule.InsertSetup(self.soltype, arg)
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _add_calculation(
         self,
         reporttype,
@@ -310,7 +316,7 @@ class CommonOptimetrics(object):
 
         return self.update()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def _add_goal(
         self,
         optigoalname,
@@ -439,7 +445,7 @@ class DXSetups(object):
         def __init__(self, app, name, dictinputs=None):
             CommonOptimetrics.__init__(self, app, name, dictinputs=dictinputs, optimtype="OptiDesignExplorer")
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def add_calculation(
             self,
             calculation="",
@@ -488,7 +494,7 @@ class DXSetups(object):
                 calculation_name=calculation_name,
             )
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def add_goal(
             self,
             calculation="",
@@ -591,7 +597,7 @@ class DXSetups(object):
             except:
                 pass
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_dx_setup(self, variables_to_include, defaults_var_values=None, setupname=None, parametricname=None):
         """Add a basic parametric setup in DesignXplorer.
 
@@ -625,6 +631,7 @@ class DXSetups(object):
         if not parametricname:
             parametricname = generate_unique_name("DesignXplorer")
         setup = self.Setup(self._app, parametricname)
+        setup.auto_update = False
         setup.props["Sim. Setups"] = setupname
         setup.props["Sweeps"] = []
         if not defaults_var_values:
@@ -648,6 +655,7 @@ class DXSetups(object):
                 setup.props["StartingPoint"][v] = vv
         setup.create()
         self.setups.append(setup)
+        setup.auto_update = True
         return setup
 
 
@@ -683,7 +691,7 @@ class ParametericsSetups(object):
             CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiParametric")
             pass
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def add_variation(self, sweep_var, datarange):
             """Add a variation to an existing parametric setup.
 
@@ -715,7 +723,7 @@ class ParametericsSetups(object):
             self.update()
             return True
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def add_calculation(
             self,
             calculation="",
@@ -796,7 +804,7 @@ class ParametericsSetups(object):
             except:
                 pass
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_parametric_setup(self, sweep_var, datarange, setupname=None, parametricname=None):
         """Add a basic parametric setup.
 
@@ -831,6 +839,7 @@ class ParametericsSetups(object):
         if not parametricname:
             parametricname = generate_unique_name("Parametric")
         setup = self.Setup(self._app, parametricname)
+        setup.auto_update = False
         setup.props["Sim. Setups"] = setupname
         sweepdefinition = OrderedDict()
         sweepdefinition["Variable"] = sweep_var
@@ -840,6 +849,7 @@ class ParametericsSetups(object):
         setup.props["Sweeps"]["SweepDefinition"] = sweepdefinition
         setup.create()
         self.setups.append(setup)
+        setup.auto_update = True
         return setup
 
 
@@ -872,7 +882,7 @@ class SensitivitySetups(object):
         def __init__(self, p_app, name, dictinputs=None):
             CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiSensitivity")
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def add_calculation(
             self,
             calculation="",
@@ -952,7 +962,7 @@ class SensitivitySetups(object):
             except:
                 pass
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_sensitivity(
         self,
         calculation,
@@ -999,6 +1009,7 @@ class SensitivitySetups(object):
         if not parametricname:
             parametricname = generate_unique_name("Sensitivity")
         setup = self.Setup(self._app, parametricname)
+        setup.auto_update = False
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
         if not solution:
@@ -1012,6 +1023,7 @@ class SensitivitySetups(object):
         )
         setup.props["Goals"]["Goal"] = sweepdefinition
         setup.create()
+        setup.auto_update = True
         self.setups.append(setup)
         return setup
 
@@ -1046,7 +1058,7 @@ class StatisticalSetups(object):
             CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiStatistical")
             pass
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def add_calculation(
             self,
             calculation="",
@@ -1126,7 +1138,7 @@ class StatisticalSetups(object):
             except:
                 pass
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_statistical(
         self,
         calculation_name,
@@ -1173,6 +1185,7 @@ class StatisticalSetups(object):
         if not parametricname:
             parametricname = generate_unique_name("Statistical")
         setup = self.Setup(self._app, parametricname)
+        setup.auto_update = False
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
         if not solution:
@@ -1187,6 +1200,7 @@ class StatisticalSetups(object):
         )
         setup.props["Goals"]["Goal"] = sweepdefinition
         setup.create()
+        setup.auto_update = True
         self.setups.append(setup)
         return setup
 
@@ -1221,7 +1235,7 @@ class DOESetups(object):
             CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiDXDOE")
             pass
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def add_calculation(
             self,
             calculation="",
@@ -1270,7 +1284,7 @@ class DOESetups(object):
                 calculation_name=calculation_name,
             )
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def add_goal(
             self,
             calculation="",
@@ -1373,7 +1387,7 @@ class DOESetups(object):
             except:
                 pass
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_doe(
         self,
         calculation,
@@ -1435,6 +1449,7 @@ class DOESetups(object):
         if not parametricname:
             parametricname = generate_unique_name("DesignOfExp")
         setup = self.Setup(self._app, parametricname)
+        setup.auto_update = False
         setup.props["Sim. Setups"] = setupname
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
@@ -1454,6 +1469,7 @@ class DOESetups(object):
         setup.props["CostFunctionGoals"]["Goal"] = sweepdefinition
         setup.create()
         self.setups.append(setup)
+        setup.auto_update = True
         return setup
 
 
@@ -1485,7 +1501,7 @@ class OptimizationSetups(object):
             CommonOptimetrics.__init__(self, p_app, name, dictinputs=dictinputs, optimtype="OptiOptimization")
             pass
 
-        @aedt_exception_handler
+        @pyaedt_function_handler()
         def add_goal(
             self,
             calculation="",
@@ -1588,7 +1604,7 @@ class OptimizationSetups(object):
             except:
                 pass
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def add_optimization(
         self,
         calculation,
@@ -1645,6 +1661,7 @@ class OptimizationSetups(object):
         if not parametricname:
             parametricname = generate_unique_name("Optimization")
         setup = self.Setup(self._app, parametricname)
+        setup.auto_update = False
         sweepdefinition = OrderedDict()
         sweepdefinition["ReportType"] = reporttype
         if not solution:
@@ -1664,5 +1681,6 @@ class OptimizationSetups(object):
 
         setup.props["Goals"]["Goal"] = sweepdefinition
         setup.create()
+        setup.auto_update = True
         self.setups.append(setup)
         return setup
