@@ -1,14 +1,18 @@
-"""This module contains these classes: `Q2d`, `Q3d`, and `QExtractor`."""
-from __future__ import absolute_import
+"""This module contains these classes: ``Q2d``, ``Q3d``, and ``QExtractor`."""
+from __future__ import absolute_import  # noreorder
+
 import os
 import warnings
+from collections import OrderedDict
 
 from pyaedt.application.Analysis2D import FieldAnalysis2D
 from pyaedt.application.Analysis3D import FieldAnalysis3D
-from pyaedt.generic.general_methods import aedt_exception_handler, generate_unique_name
-from collections import OrderedDict
-from pyaedt.modules.Boundary import BoundaryObject, Matrix
-from pyaedt.generic.constants import MATRIXOPERATIONSQ2D, MATRIXOPERATIONSQ3D
+from pyaedt.generic.constants import MATRIXOPERATIONSQ2D
+from pyaedt.generic.constants import MATRIXOPERATIONSQ3D
+from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import pyaedt_function_handler
+from pyaedt.modules.Boundary import BoundaryObject
+from pyaedt.modules.Boundary import Matrix
 
 
 class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
@@ -93,18 +97,19 @@ class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
         """
         return self.matrices[0].sources(False)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def insert_reduced_matrix(self, operation_name, source_names=None, rm_name=None):
         """Insert a new reduced matrix.
 
         Parameters
         ----------
         operation_name : str
-            Name of the Operation to create.
+            Name of the operation to create.
         source_names : list, str, optional
-            List of sources or nets or arguments needed for specific operation.
+            List of sources or nets or arguments needed for the operation. The default
+            is ``None``.
         rm_name : str, optional
-            Name of the reduced matrix, optional.
+            Name of the reduced matrix The default is ``None``.
 
         Returns
         -------
@@ -118,6 +123,53 @@ class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
             self.matrices.append(matrix)
         return matrix
 
+    @pyaedt_function_handler()
+    def get_traces_for_plot(
+        self,
+        get_self_terms=True,
+        get_mutual_terms=True,
+        first_element_filter=None,
+        second_element_filter=None,
+        category="C",
+    ):
+        """Retrieve a list of traces of specified designs ready to use in plot reports.
+
+        Parameters
+        ----------
+        get_self_terms : bool, optional
+            Whether to return self terms. The default is ``True``.
+        get_mutual_terms : bool, optional
+            Whether to return mutual terms. The default is ``True``.
+        first_element_filter : str, optional
+            Filter to apply to the first element of the equation. This parameter accepts ``*``
+            and ``?`` as special characters. The default is ``None``.
+        second_element_filter : str, optional
+            Filter to apply to the second element of the equation. This parameter accepts ``*``
+            and ``?`` as special characters. The default is ``None``.
+        category : str
+            Plot category name as in the report (including operator). The default is ``"C"`,
+            which is the plot category name for capacitance.
+
+        Returns
+        -------
+        list
+            List of traces of specified designs ready to use in plot reports.
+
+        Examples
+        --------
+        >>> from pyaedt import Q3d
+        >>> hfss = Q3d(project_path)
+        >>> hfss.get_traces_for_plot(first_element_filter="Bo?1",
+        ...                           second_element_filter="GND*", category="C")
+        """
+        return self.matrices[0].get_sources_for_plot(
+            get_self_terms=get_self_terms,
+            get_mutual_terms=get_mutual_terms,
+            first_element_filter=first_element_filter,
+            second_element_filter=second_element_filter,
+            category=category,
+        )
+
 
 class Q3d(QExtractor, object):
     """Provides the Q3D application interface.
@@ -147,10 +199,10 @@ class Q3d(QExtractor, object):
         Version of AEDT to use. The default is ``None``, in which case
         the active version or latest installed version is used.
         This parameter is ignored when Script is launched within AEDT.
-    NG : bool, optional
-        Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical mode.
-        This parameter is ignored when Script is launched within AEDT.
+    non_graphical : bool, optional
+        Whether to launch AEDT in non-graphical mode. The default
+        is ``False``, in which case AEDT is launched in graphical mode.
+        This parameter is ignored when a script is launched within AEDT.
     new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
@@ -200,7 +252,7 @@ class Q3d(QExtractor, object):
 
     @property
     def nets(self):
-        """Return the list of available nets in actual Q3d Project.
+        """Return the list of available nets in a Q3D project.
 
         Returns
         -------
@@ -218,9 +270,9 @@ class Q3d(QExtractor, object):
                 net_names.append(i[0].split(":")[1])
         return net_names
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def net_sources(self, net_name):
-        """Check if a net has sources and returns the list of names.
+        """Check if a net has sources and return a list of source names.
 
         Parameters
         ----------
@@ -230,7 +282,7 @@ class Q3d(QExtractor, object):
         Returns
         -------
         List
-            List of Source names.
+            List of source names.
 
         Examples
         --------
@@ -251,9 +303,9 @@ class Q3d(QExtractor, object):
 
         return sources
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def net_sinks(self, net_name):
-        """Check if a net has sinks and returns the list of them.
+        """Check if a net has sinks and returns a list of sink names.
 
         Parameters
         ----------
@@ -263,7 +315,7 @@ class Q3d(QExtractor, object):
         Returns
         -------
         List
-            List of Sink names.
+            List of sink names.
 
         Examples
         --------
@@ -282,7 +334,7 @@ class Q3d(QExtractor, object):
                 sinks.append(i.name)
         return sinks
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def auto_identify_nets(self):
         """Automatically identify nets.
 
@@ -312,18 +364,20 @@ class Q3d(QExtractor, object):
             self.logger.info("No new nets identified")
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_net(self, objects, net_name=None, net_type="Signal"):
         """Assign a net to a list of objects.
 
         Parameters
         ----------
-        objects : List, str
-            List of objects to assign net. Can be a single object.
+        objects : list, str
+            List of objects to assign the net to. It can be a single object.
         net_name : str, optional
-            Name of the net. If `None`, default net name will be provided.
-        net_type : str, boolean
-            Type of net to create. Can be `Signal`, `Ground` or `Floating`.
+            Name of the net. The default is ```None``, in which case the
+            default name is used.
+        net_type : str, bool
+            Type of net to create. Options are ``"Signal"``, ``"Ground"`` and ``"Floating"``.
+            The default is ``"Signal"``.
 
         Returns
         -------
@@ -360,20 +414,19 @@ class Q3d(QExtractor, object):
             return bound
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_source_to_objectface(self, object_name, axisdir=0, source_name=None, net_name=None):
         """Generate a source on a face of an object.
 
-        The face ID is selected based on ``axisdir``. It is the face that
+        The face ID is selected based on the axis direction. It is the face that
         has the maximum/minimum in this axis direction.
 
         Parameters
         ----------
         object_name : str, int
             Name of the object or face id.
-            Name of the object.
-        axisdir : optional
-            Initial axis direction. Options are ``0`` through ``5``. The default is ``0``.
+        axisdir : int, optional
+            Initial axis direction. Options are ``0`` to ``5``. The default is ``0``.
         source_name : str, optional
             Name of the source. The default is ``None``.
         net_name : str, optional
@@ -408,7 +461,7 @@ class Q3d(QExtractor, object):
                 return bound
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_source_to_sheet(self, sheetname, objectname=None, netname=None, sourcename=None):
         """Generate a source on a sheet.
 
@@ -449,11 +502,11 @@ class Q3d(QExtractor, object):
             return bound
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_sink_to_objectface(self, object_name, axisdir=0, sink_name=None, net_name=None):
         """Generate a sink on a face of an object.
 
-        The face ID is selected based on ``axisdir``. It is the face that has
+        The face ID is selected based on the axis direction. It is the face that has
         the maximum/minimum in this axis direction.
 
         Parameters
@@ -461,7 +514,7 @@ class Q3d(QExtractor, object):
         object_name : str, int
             Name of the object or face id.
         axisdir : int, optional
-            Initial axis direction. Options are ``0`` through ``5``. The default is ``0``.
+            Initial axis direction. Options are ``0`` to ``5``. The default is ``0``.
         sink_name : str, optional
             Name of the sink. The default is ``None``.
         net_name : str, optional
@@ -497,7 +550,7 @@ class Q3d(QExtractor, object):
                 return bound
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_sink_to_sheet(self, sheetname, objectname=None, netname=None, sinkname=None):
         """Generate a sink on a sheet.
 
@@ -539,7 +592,7 @@ class Q3d(QExtractor, object):
             return bound
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_frequency_sweep(self, setupname, units, freqstart, freqstop, freqstep=None, sweepname=None):
         """Create a frequency sweep.
 
@@ -548,7 +601,7 @@ class Q3d(QExtractor, object):
         setupname : str
             Name of the setup that is attached to the sweep.
         units : str
-            Unit of the frequency. For example, ``"MHz"`` or
+            Units of the frequency. For example, ``"MHz"`` or
             ``"GHz"``. The default is ``"GHz"``.
         freqstart :
             Starting frequency of the sweep.
@@ -599,7 +652,7 @@ class Q3d(QExtractor, object):
                 return sweepdata
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_discrete_sweep(
         self, setupname, freqstart, freqstop=None, freqstep=None, units="GHz", sweepname=None, savefields=False
     ):
@@ -613,13 +666,13 @@ class Q3d(QExtractor, object):
             Starting point for the discrete frequency.
         freqstop : float, optional
             Stopping point for the discrete frequency. If ``None``,
-            a single-point sweep is to be performed.
+            a single-point sweep is performed.
         freqstep : float, optional
             Step point for the discrete frequency. If ``None``,
-            11 points will be created.
+            11 points are created.
         units : str, optional
-            Unit of the discrete frequency. For example, ``"MHz"`` or
-            ``"GHz"``.The default is ``"GHz"``.
+            Units of the discrete frequency. For example, ``"MHz"`` or
+            ``"GHz"``. The default is ``"GHz"``.
         sweepname : str, optional
             Name of the sweep.
         savefields : bool, optional
@@ -645,7 +698,7 @@ class Q3d(QExtractor, object):
                 setupdata = i
                 for sw in setupdata.sweeps:
                     if sweepname == sw.name:
-                        self.logger.warning("Sweep %s already present. Please rename and retry", sweepname)
+                        self.logger.warning("Sweep %s already present. Rename and retry.", sweepname)
                         return False
                 sweepdata = setupdata.add_sweep(sweepname, "Discrete")
                 sweepdata.props["RangeStart"] = str(freqstart) + "GHz"
@@ -694,10 +747,10 @@ class Q2d(QExtractor, object):
         Version of AEDT to use. The default is ``None``, in which case
         the active version or latest installed version is used.  This
         parameter is ignored when Script is launched within AEDT.
-    NG : bool, optional
-        Whether to launch AEDT in the non-graphical mode. The default
-        is ``False``, in which case AEDT is launched in the graphical mode.
-        This parameter is ignored when Script is launched within AEDT.
+    non_graphical : bool, optional
+        Whether to launch AEDT in non-graphical mode. The default
+        is ``False``, in which case AEDT is launched in graphical mode.
+        This parameter is ignored when a script is launched within AEDT.
     new_desktop_session : bool, optional
         Whether to launch an instance of AEDT in a new thread, even if
         another instance of the ``specified_version`` is active on the
@@ -762,7 +815,7 @@ class Q2d(QExtractor, object):
         )
         self.MATRIXOPERATIONS = MATRIXOPERATIONSQ2D()
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def create_rectangle(self, position, dimension_list, name="", matname=""):
         """
         Create a rectangle.
@@ -770,15 +823,16 @@ class Q2d(QExtractor, object):
         Parameters
         ----------
         position : list
-            List of [x, y] coordinates for the starting point of the rectangle.
+            List of ``[x, y]`` coordinates for the starting point of the rectangle.
         dimension_list : list
-            List of [width, height] dimensions.
+            List of ``[width, height]`` dimensions.
         name : str, optional
             Name of the rectangle. The default is ``None``, in which case
             the default name is assigned.
         matname : str, optional
             Name of the material. The default is ``None``, in which case
             the default material is assigned.
+
         Returns
         -------
         pyaedt.modeler.Object3d.Object3d
@@ -791,23 +845,23 @@ class Q2d(QExtractor, object):
         """
         return self.modeler.create_rectangle(position, dimension_list=dimension_list, name=name, matname=matname)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_single_signal_line(self, target_objects, name="", solve_option="SolveInside", thickness=None, unit="um"):
-        """Assign conductor type to sheets.
+        """Assign the conductor type to sheets.
 
         Parameters
         ----------
         target_objects : list
             List of Object3D.
-        name : str
-            Name of the conductor.
+        name : str, optional
+            Name of the conductor. The default is ``""``.
         solve_option : str, optional
-            Method for solving. Options are ``"SolveInside"``, ``"SolveOnBoundary"`` or ``"Automatic"``. The default is
-            ``"SolveInside"``.
+            Method for solving. Options are ``"SolveInside"``, ``"SolveOnBoundary"``, and ``"Automatic"``.
+            The default is ``"SolveInside"``.
         thickness : float, optional
-            Conductor thickness. The default is ``None``, in which case the conductor thickness is obtained by dividing
-            the conductor's area by its perimeter (A/p). If multiple conductors are selected, the average conductor
-            thickness is used.
+            Conductor thickness. The default is ``None``, in which case the conductor thickness
+            is obtained by dividing the conductor's area by its perimeter (A/p). If multiple
+            conductors are selected, the average conductor thickness is used.
         unit : str, optional
             Thickness unit. The default is ``"um"``.
 
@@ -823,7 +877,7 @@ class Q2d(QExtractor, object):
         )
         self.assign_single_conductor(target_objects, name, "SignalLine", solve_option, thickness, unit)
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_single_conductor(
         self,
         target_objects,
@@ -834,19 +888,20 @@ class Q2d(QExtractor, object):
         unit="um",
     ):
         """
-        Assign conductor type to sheets.
+        Assign the conductor type to sheets.
 
         Parameters
         ----------
         target_objects : list
             List of Object3D.
-        name : str
-            Name of the conductor.
+        name : str, optional
+            Name of the conductor. The default is ``""``.
         conductor_type : str
-            Type of conductor. Options are ``"SignalLine"``, ``"ReferenceGround"``. The default is SignalLine.
+            Type of the conductor. Options are ``"SignalLine"`` and ``"ReferenceGround"``. The default is
+            ``"SignalLine"``.
         solve_option : str, optional
-            Method for solving. Options are ``"SolveInside"``, ``"SolveOnBoundary"`` or ``"Automatic"``. The default is
-            ``"SolveInside"``.
+            Method for solving. Options are ``"SolveInside"``, ``"SolveOnBoundary"``, and ``"Automatic"``.
+            The default is ``"SolveInside"``.
         thickness : float, optional
             Conductor thickness. The default is ``None``, in which case the conductor thickness is obtained by dividing
             the conductor's area by its perimeter (A/p). If multiple conductors are selected, the average conductor
@@ -892,19 +947,20 @@ class Q2d(QExtractor, object):
             return bound
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def assign_huray_finitecond_to_edges(self, edges, radius, ratio, unit="um", name=""):
         """
-        Assign Huray surface roughness model to edges.
+        Assign the Huray surface roughness model to edges.
 
         Parameters
         ----------
+        edges :
         radius :
         ratio :
-        unit :
-        edges :
-        name :
-        model_type :
+        unit : str, optional
+            The default is ``"um"``.
+        name : str, optional
+            The default is ``""``.
 
         Returns
         -------
@@ -934,13 +990,14 @@ class Q2d(QExtractor, object):
             return bound
         return False
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def auto_assign_conductors(self):
-        """Auto Assign Conductors to Signal Lines.
+        """Automatically assign conductors to signal lines.
 
         Returns
         -------
         bool
+            ``True`` when successful, ``False`` when failed.
         """
         original_nets = list(self.oboundary.GetExcitations())
         self.oboundary.AutoAssignSignals()
@@ -960,7 +1017,7 @@ class Q2d(QExtractor, object):
             self.logger.info("No new nets identified")
         return True
 
-    @aedt_exception_handler
+    @pyaedt_function_handler()
     def toggle_conductor_type(self, conductor_name, new_type):
         """Change the conductor type.
 
@@ -974,6 +1031,7 @@ class Q2d(QExtractor, object):
         Returns
         -------
         bool
+            ``True`` when successful, ``False`` when failed.
         """
         try:
             self.oboundary.ToggleConductor(conductor_name, new_type)
